%global pypi_name email-validator

Name:           python-%{pypi_name}
Version:        2.2.0
Release:        %mkrel 2
Summary:        A robust email syntax and deliverability validation library
Group:          Development/Python
License:        CC0
URL:            https://github.com/JoshData/python-email-validator
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildArch:      noarch

%description
This library validates that address are of the form x@y.com. This is the sort
of validation you would want for a login form on a website.

Key features:

- Good for validating email addresses used for logins/identity.
- Friendly error messages when validation fails (appropriate to show to end
  users).
- (optionally) Checks deliverability: Does the domain name resolve?
- Supports internationalized domain names and (optionally) internationalized
  local parts.
- Normalizes email addresses (important for internationalized addresses!).

%package -n     python3-%{pypi_name}
Summary:        A robust email syntax and deliverability validation library

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-dnspython
BuildRequires:  python3-idna
BuildRequires:  python3-coverage
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
This library validates that address are of the form x@y.com. This is the sort
of validation you would want for a login form on a website.

Key features:

- Good for validating email addresses used for logins/identity.
- Friendly error messages when validation fails (appropriate to show to end
  users).
- (optionally) Checks deliverability: Does the domain name resolve?
- Supports internationalized domain names and (optionally) internationalized
  local parts.
- Normalizes email addresses (important for internationalized addresses!).

%prep
%autosetup -n python-%{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files email_validator

%check
# Even though we have disabled the “network” mark, these still require DNS.
ignore="${ignore-} --ignore=tests/test_deliverability.py"
ignore="${ignore-} --ignore=tests/test_main.py"
%pytest -v tests -m 'not network' ${ignore-}
# Just to be sure, since we have disabled some tests:
%pyproject_check_import

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc CONTRIBUTING.md README.md
%{_bindir}/email_validator


%changelog
* Sun Mar 02 2025 wally <wally> 2.2.0-2.mga10
+ Revision: 2156941
- rebuild for python3.13

* Thu Jun 27 2024 papoteur <papoteur> 2.2.0-1.mga10
+ Revision: 2077271
- new version 2.2.0

* Sun Feb 25 2024 daviddavid <daviddavid> 2.1.0-1.mga10
+ Revision: 2044120
- new version: 2.1.0
- switch to pyproject
- rebuild for py3.12

* Thu Mar 31 2022 umeabot <umeabot> 1.1.3-3.mga9
+ Revision: 1835773
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 mrambo3501 <mrambo3501> 1.1.3-2.mga9
+ Revision: 1785007
- rebuild for python-3.10

* Sat Aug 28 2021 wally <wally> 1.1.3-1.mga9
+ Revision: 1743216
- new version 1.1.3
- skip more tests requiring internet access

* Sat Jun 26 2021 wally <wally> 1.1.1-4.mga9
+ Revision: 1732957
- Rebuild for python 3.9

* Mon Aug 10 2020 ngompa <ngompa> 1.1.1-3.mga8
+ Revision: 1612536
- Adapt for Mageia
- imported package python-email-validator


* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jun 03 2020 Fabian Affolter <mail@fabian-affolter.ch> - 1.1.1-1
- Enable tests
- Update to new upstream release 1.1.1

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.0.5-4
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Jan 07 2020 Fabian Affolter <mail@fabian-affolter.ch> - 1.0.5-2
- Implement changes from rhbz#1787419 to match rhbz#1733683

* Mon Jan 06 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.0.5-1
- Update to 1.0.5.
- Review fixes.

* Sat Jul 27 2019 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.0.4-1
- Initial package.
